@@ -47,7 +47,7 @@ sub import {
 }
 
 
-our $VERSION = '0.0180';    # VERSION
+our $VERSION = '0.0181';    # VERSION
 
 1;
 
@@ -65,7 +65,7 @@ Evo - Evo - the next generation component-oriented development framework
 
 =head1 VERSION
 
-version 0.0180
+version 0.0181
 
 =head1 DESCRIPTION
 
@@ -129,7 +129,7 @@ Shortcuts are used to make life easily during code refactoring (and you module s
 
 C<-> is replaced by C<Evo>
 
-  use Evo '-Promises promise';
+  use Evo '-Promises promise'; # "Evo::Promises promise"
 
 C<:> and C<::> make sense in the package and depends on the package name where is used
 
