@@ -1,5 +1,5 @@
 package Evo::Lib;
-use Evo '-Export *', -Util, 'Carp croak';
+use Evo '-Export *', -Util;
 use Time::HiRes qw(CLOCK_MONOTONIC clock_gettime);
 
 PATCH: {
@@ -41,7 +41,7 @@ Evo::Lib
 
 =head1 VERSION
 
-version 0.0180
+version 0.0181
 
 =head1 AUTHOR
 
